==> trade-center-api-2.4.8-sources.jar: cn/com/duiba/order/center/api/remoteservice/RemoteConsumerOrderSimpleService.java <==
package cn.com.duiba.order.center.api.remoteservice;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.order.center.api.dto.AppItemExchangeDto;
import cn.com.duiba.order.center.api.dto.MailaItemDto;
import cn.com.duiba.order.center.api.dto.OrdersDto;
import cn.com.duiba.wolf.dubbo.DubboResult;
import org.springframework.web.bind.annotation.RequestMapping;

import java.util.Date;
import java.util.List;

/**
 * Created by yansen on 16/9/22.
 * 主订单--用户维度拆分表--基础接口
 */
@AdvancedFeignClient
public interface RemoteConsumerOrderSimpleService {


    /**
     * 根据订单id和用户id查询订单
     * @param id
     * @param consumerId
     * @return
     */
    @RequestMapping("/findByIdAndCid")
    public DubboResult<OrdersDto> findById(Long id, Long consumerId);
    
    /**
     * 根据多个id查询订单--警告调用者list长度不宜过长
     * @param ids
     * @param consumerId
     * @return
     */
    DubboResult<List<OrdersDto>> findByIds(List<Long> ids, Long consumerId);

    DubboResult<List<OrdersDto>> findByIdsWithTable(List<Long> ids, String tableName);
    
    /**
     * 根据多个id查询订单，返回数据和sequence顺序一致--警告调用者list长度不宜过长
     * @param ids
     * @param sequence id逗号隔开，返回数据的顺序和sequence顺序一致
     * @param consumerId
     * @return
     */
    DubboResult<List<OrdersDto>> findByIdsInSequence(List<Long> ids, String sequence, Long consumerId);

    /**
     * 根据订单唯一编号查询订单
     * @param orderNum
     * @return
     */
    public DubboResult<OrdersDto> findByOrderNum(String orderNum);

    /**
     * 通过for update的方式查询订单
     * @param orderId
     * @param consumerId
     * @return
     */
    public DubboResult<OrdersDto> select4updatelock(Long orderId, Long consumerId);

    /**
     * 根据订单id查询订单
     * @param id
     * @return
     */
    DubboResult<OrdersDto> findById(Long id);
    
    /**
     * 用户和商品维度，查询订单--商品数量最大20
     * @param consumerId
     * @param itemIds
     * @return
     */
    DubboResult<List<MailaItemDto>> findByItem(Long consumerId, List<Long> itemIds);

    /**
     * 用户和应用商品维度，查询商品兑换信息
     * @param consumerId
     * @param appItemIds
     * @param gmtCreate
     * @return
     */
    List<AppItemExchangeDto> findByAppItem(Long consumerId, List<Long> appItemIds, Date gmtCreate);

	/**
     * 订单同步的消息,防止出现因为订单消息丢失导致的订单不同步
     * @param orderId
     * @param cousumerId
     * @return
     */
    void  syncOrder(Long orderId,Long cousumerId);


    /**
     * 仅试用新订单号
     * 仅根据 订单id 查询 ，特殊需求 才使用该接口
     * */
    List<OrdersDto> queryByOrderIds(List<Long> orderIds);

    /**
     * 仅试用新订单号
     * 仅根据 订单id 查询 ，特殊需求 才使用该接口
     * */
    List<OrdersDto> findByIdsAndSuffix(List<Long> orderIds, String tableSuffix);

    /**
     * 农总行-修改收货地址并打标记
     *
     * @param orderId   订单id
     * @param bizParams 收货地址
     * @param extraInfo 定制信息
     * @return 影响行数
     */
    Integer updateAddressAndMark(Long orderId, String bizParams, String extraInfo, Long consumerId);

    /**
     * 根据订单状态StatusIntEnum
     * */
    List<OrdersDto> getOrderList(Long cid, Integer pageNum, Integer status);
}

==> trade-center-api-2.4.24-20220614.034815-1-sources.jar: cn/com/duiba/order/center/api/remoteservice/RemoteConsumerOrderSimpleService.java <==
package cn.com.duiba.order.center.api.remoteservice;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.order.center.api.dto.AppItemExchangeDto;
import cn.com.duiba.order.center.api.dto.MailaItemDto;
import cn.com.duiba.order.center.api.dto.OrdersDto;
import cn.com.duiba.wolf.dubbo.DubboResult;
import org.springframework.web.bind.annotation.RequestMapping;

import java.util.Date;
import java.util.List;

/**
 * Created by yansen on 16/9/22.
 * 主订单--用户维度拆分表--基础接口
 */
@AdvancedFeignClient
public interface RemoteConsumerOrderSimpleService {


    /**
     * 根据订单id和用户id查询订单
     * @param id
     * @param consumerId
     * @return
     */
    @RequestMapping("/findByIdAndCid")
    public DubboResult<OrdersDto> findById(Long id, Long consumerId);
    
    /**
     * 根据多个id查询订单--警告调用者list长度不宜过长
     * @param ids
     * @param consumerId
     * @return
     */
    DubboResult<List<OrdersDto>> findByIds(List<Long> ids, Long consumerId);

    DubboResult<List<OrdersDto>> findByIdsWithTable(List<Long> ids, String tableName);
    
    /**
     * 根据多个id查询订单，返回数据和sequence顺序一致--警告调用者list长度不宜过长
     * @param ids
     * @param sequence id逗号隔开，返回数据的顺序和sequence顺序一致
     * @param consumerId
     * @return
     */
    DubboResult<List<OrdersDto>> findByIdsInSequence(List<Long> ids, String sequence, Long consumerId);

    /**
     * 根据订单唯一编号查询订单
     * @param orderNum
     * @return
     */
    public DubboResult<OrdersDto> findByOrderNum(String orderNum);

    /**
     * 通过for update的方式查询订单
     * @param orderId
     * @param consumerId
     * @return
     */
    public DubboResult<OrdersDto> select4updatelock(Long orderId, Long consumerId);

    /**
     * 根据订单id查询订单
     * @param id
     * @return
     */
    DubboResult<OrdersDto> findById(Long id);
    
    /**
     * 用户和商品维度，查询订单--商品数量最大20
     * @param consumerId
     * @param itemIds
     * @return
     */
    DubboResult<List<MailaItemDto>> findByItem(Long consumerId, List<Long> itemIds);

    /**
     * 用户和应用商品维度，查询商品兑换信息
     * @param consumerId
     * @param appItemIds
     * @param gmtCreate
     * @return
     */
    List<AppItemExchangeDto> findByAppItem(Long consumerId, List<Long> appItemIds, Date gmtCreate);

	/**
     * 订单同步的消息,防止出现因为订单消息丢失导致的订单不同步
     * @param orderId
     * @param cousumerId
     * @return
     */
    void  syncOrder(Long orderId,Long cousumerId);


    /**
     * 仅试用新订单号
     * 仅根据 订单id 查询 ，特殊需求 才使用该接口
     * */
    List<OrdersDto> queryByOrderIds(List<Long> orderIds);

    /**
     * 仅试用新订单号
     * 仅根据 订单id 查询 ，特殊需求 才使用该接口
     * */
    List<OrdersDto> findByIdsAndSuffix(List<Long> orderIds, String tableSuffix);

    /**
     * 农总行-修改收货地址并打标记
     *
     * @param orderId   订单id
     * @param bizParams 收货地址
     * @param extraInfo 定制信息
     * @return 影响行数
     */
    Integer updateAddressAndMark(Long orderId, String bizParams, String extraInfo, Long consumerId);

    /**
     * 根据订单状态StatusIntEnum
     * */
    List<OrdersDto> getOrderList(Long cid, Integer pageNum, Integer status);

    /**
     * 根据订单状态和是否普兑查询订单   StatusIntEnum
     * */
    public List<OrdersDto> getOrderListByChargeMode(Long cid, Integer pageNum, Integer status, String chargeMode);
}
